
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.30.6',
    'branch_nick': 'release-1.30',
    'revision_id': '82390181cf8dc300ec59afeb569ad0be93819e7f',
    'revno': 12373
}
